@@ -30,17 +30,20 @@ headers = {"Content-type": "application/json", "Authorization": "header"}
 
 
 class TestPostRequest:
-    def test_post_request_pass(self, post, response):
+    def test_post_request_pass(self, post, response, mocker):
         request = {"a": "b"}
         response._content = b'{"a": "b"}'
         assert tuxsuite.build.post_request(
             url="http://foo.bar.com/pass", headers=headers, request=request
         ) == {"a": "b"}
         post.assert_called_with(
-            "http://foo.bar.com/pass", data='{"a": "b"}', headers=headers
+            "http://foo.bar.com/pass",
+            data='{"a": "b"}',
+            headers=headers,
+            timeout=mocker.ANY,
         )
 
-    def test_post_request_timeout(self, post, response):
+    def test_post_request_timeout(self, post, response, mocker):
         request = {"a": "b"}
         response.status_code = 504
 
@@ -61,13 +64,15 @@ class TestPostRequest:
 
 
 class TestGetRequest:
-    def test_get_request_pass(self, get, response):
+    def test_get_request_pass(self, get, response, mocker):
         response._content = b'{"a": "b"}'
 
         assert tuxsuite.build.get_request(
             url="http://foo.bar.com/pass", headers=headers
         ) == {"a": "b"}
-        get.assert_called_with("http://foo.bar.com/pass", headers=headers)
+        get.assert_called_with(
+            "http://foo.bar.com/pass", headers=headers, timeout=mocker.ANY
+        )
 
     def test_get_request_timeout(self, get, response):
         response.status_code = 504
@@ -138,6 +143,7 @@ def build_attrs():
         "toolchain": "gcc-9",
         "token": "test_token",
         "kbapi_url": "http://test/foo",
+        "kernel_image": "Image",
     }
 
 
@@ -219,6 +225,7 @@ class TestBuild:
                     "environment": {},
                     "targets": [],
                     "make_variables": {},
+                    "kernel_image": build_attrs["kernel_image"],
                 }
             ],
         )
@@ -245,6 +252,7 @@ class TestBuild:
                     "environment": {},
                     "targets": [],
                     "make_variables": {},
+                    "kernel_image": build_attrs["kernel_image"],
                 }
             ],
         )
@@ -283,6 +291,7 @@ class TestBuild:
                     "environment": build_attrs["environment"],
                     "targets": [],
                     "make_variables": {},
+                    "kernel_image": build_attrs["kernel_image"],
                 }
             ],
         )
@@ -311,6 +320,7 @@ class TestBuild:
                     "targets": build_attrs["targets"],
                     "environment": {},
                     "make_variables": {},
+                    "kernel_image": build_attrs["kernel_image"],
                 }
             ],
         )
@@ -339,6 +349,7 @@ class TestBuild:
                     "targets": [],
                     "environment": {},
                     "make_variables": {"W": "12", "LLVM": "1"},
+                    "kernel_image": build_attrs["kernel_image"],
                 }
             ],
         )
