@@ -107,6 +107,26 @@ def test_build_git_sha(mocker, tuxsuite_config):
     assert wait_for_object.call_count == 1
 
 
+def test_build_kernel_image(mocker, tuxsuite_config):
+    build = mocker.patch("tuxsuite.Build.build")
+    wait_for_object = mocker.patch("tuxsuite.cli.wait_for_object")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxsuite.cli.build,
+        [
+            "--git-repo=https://git.example.com/linux.git",
+            "--git-sha=beefbee",
+            "--target-arch=arm64",
+            "--kconfig=defconfig",
+            "--toolchain=gcc-9",
+            "--kernel-image=Image",
+        ],
+    )
+    assert result.exit_code == 0
+    assert build.call_count == 1
+    assert wait_for_object.call_count == 1
+
+
 def test_build_git_head(mocker, tuxsuite_config):
     get_git_head = mocker.patch("tuxsuite.gitutils.get_git_head")
     get_git_head.return_value = ("https://example.com/linux.git", "deadbeef")
@@ -135,6 +155,7 @@ def test_build_git_head(mocker, tuxsuite_config):
         targets=[],
         make_variables={},
         build_name=None,
+        kernel_image=None,
     )
     wait_for_object.assert_called()
     assert result.exit_code == 0
