@@ -81,6 +81,7 @@ class Build(HeadersMixin):
     environment = attrib(default={})
     targets = attrib(default=[])
     make_variables = attrib(default={})
+    kernel_image = attrib(default=None)
 
     build_data = attrib(default=None)
     build_key = attrib(default=None)
@@ -131,6 +132,8 @@ class Build(HeadersMixin):
         build_entry["environment"] = dict(self.environment)
         build_entry["targets"] = self.targets
         build_entry["make_variables"] = self.make_variables
+        if self.kernel_image:
+            build_entry["kernel_image"] = self.kernel_image
         if self.build_name:
             build_entry["build_name"] = self.build_name
         return build_entry
@@ -184,7 +187,7 @@ class Build(HeadersMixin):
                 build=self,
                 state="provisioning",
                 message="Provisioning",
-                icon="⚙️",
+                icon="⚙️ ",
                 cli_color="white",
             ),
             "building": BuildState(
