@@ -101,6 +101,10 @@ def common_options(required):
             "--target-arch",
             help="Target architecture [arc|arm|arm64|i386|mips|parisc|powerpc|riscv|s390|sh|sparc|x86_64]",
         ),
+        option(
+            "--kernel-image",
+            help="Specify custom kernel image that you wish to build",
+        ),
         option(
             "--kconfig",
             multiple=True,
